@@ -26,7 +26,7 @@ use deno_core::serde_json::json;
 use deno_core::url::Position;
 use deno_core::url::Url;
 use deno_core::ModuleSpecifier;
-use deno_runtime::deno_web::BlobUrlStore;
+use deno_runtime::deno_web::BlobStore;
 use deno_runtime::permissions::Permissions;
 use log::error;
 use lspower::lsp;
@@ -264,7 +264,7 @@ impl Default for ModuleRegistry {
       cache_setting,
       true,
       None,
-      BlobUrlStore::default(),
+      BlobStore::default(),
     )
     .unwrap();
 
@@ -283,7 +283,7 @@ impl ModuleRegistry {
       CacheSetting::Use,
       true,
       None,
-      BlobUrlStore::default(),
+      BlobStore::default(),
     )
     .context("Error creating file fetcher in module registry.")
     .unwrap();
