@@ -1,8 +1,9 @@
+import { copy } from "../../test_util/std/io/util.ts";
 async function main(): Promise<void> {
   for (let i = 1; i < Deno.args.length; i++) {
     const filename = Deno.args[i];
     const file = await Deno.open(filename);
-    await Deno.copy(file, Deno.stdout);
+    await copy(file, Deno.stdout);
   }
 }
 
