@@ -10,8 +10,11 @@ use deno_core::error::anyhow;
 use deno_core::error::bail;
 use deno_core::error::AnyError;
 use deno_core::error::Context;
+use deno_core::located_script_name;
 use deno_core::op_sync;
+use deno_core::parking_lot::Mutex;
 use deno_core::resolve_url_or_path;
+use deno_core::serde::de;
 use deno_core::serde::Deserialize;
 use deno_core::serde::Serialize;
 use deno_core::serde_json;
@@ -25,7 +28,6 @@ use deno_core::Snapshot;
 use std::collections::HashMap;
 use std::path::PathBuf;
 use std::sync::Arc;
-use std::sync::Mutex;
 
 // Declaration files
 
@@ -42,6 +44,11 @@ pub static DENO_WEBSTORAGE_LIB: &str =
 pub static DENO_CRYPTO_LIB: &str = include_str!(env!("DENO_CRYPTO_LIB_PATH"));
 pub static DENO_BROADCAST_CHANNEL_LIB: &str =
   include_str!(env!("DENO_BROADCAST_CHANNEL_LIB_PATH"));
+pub static DENO_NET_LIB: &str = include_str!(env!("DENO_NET_LIB_PATH"));
+pub static DENO_NET_UNSTABLE_LIB: &str =
+  include_str!(env!("DENO_NET_UNSTABLE_LIB_PATH"));
+pub static DENO_HTTP_UNSTABLE_LIB: &str =
+  include_str!(env!("DENO_HTTP_UNSTABLE_LIB_PATH"));
 pub static SHARED_GLOBALS_LIB: &str =
   include_str!("dts/lib.deno.shared_globals.d.ts");
 pub static WINDOW_LIB: &str = include_str!("dts/lib.deno.window.d.ts");
@@ -179,6 +186,7 @@ pub struct Request {
   pub debug: bool,
   pub graph: Arc<Mutex<Graph>>,
   pub hash_data: Vec<Vec<u8>>,
+  pub maybe_config_specifier: Option<ModuleSpecifier>,
   pub maybe_tsbuildinfo: Option<String>,
   /// A vector of strings that represent the root/entry point modules for the
   /// program.
@@ -203,6 +211,7 @@ struct State {
   hash_data: Vec<Vec<u8>>,
   emitted_files: Vec<EmittedFile>,
   graph: Arc<Mutex<Graph>>,
+  maybe_config_specifier: Option<ModuleSpecifier>,
   maybe_tsbuildinfo: Option<String>,
   maybe_response: Option<RespondArgs>,
   root_map: HashMap<String, ModuleSpecifier>,
@@ -212,6 +221,7 @@ impl State {
   pub fn new(
     graph: Arc<Mutex<Graph>>,
     hash_data: Vec<Vec<u8>>,
+    maybe_config_specifier: Option<ModuleSpecifier>,
     maybe_tsbuildinfo: Option<String>,
     root_map: HashMap<String, ModuleSpecifier>,
     data_url_map: HashMap<String, ModuleSpecifier>,
@@ -221,6 +231,7 @@ impl State {
       hash_data,
       emitted_files: Default::default(),
       graph,
+      maybe_config_specifier,
       maybe_tsbuildinfo,
       maybe_response: None,
       root_map,
@@ -228,9 +239,16 @@ impl State {
   }
 }
 
-fn op<F>(op_fn: F) -> Box<OpFn>
+fn normalize_specifier(specifier: &str) -> Result<ModuleSpecifier, AnyError> {
+  resolve_url_or_path(&specifier.replace(".d.ts.d.ts", ".d.ts"))
+    .map_err(|err| err.into())
+}
+
+fn op<F, V, R>(op_fn: F) -> Box<OpFn>
 where
-  F: Fn(&mut State, Value) -> Result<Value, AnyError> + 'static,
+  F: Fn(&mut State, V) -> Result<R, AnyError> + 'static,
+  V: de::DeserializeOwned,
+  R: Serialize + 'static,
 {
   op_sync(move |s, args, _: ()| {
     let state = s.borrow_mut::<State>();
@@ -255,6 +273,15 @@ fn op_create_hash(state: &mut State, args: Value) -> Result<Value, AnyError> {
   Ok(json!({ "hash": hash }))
 }
 
+fn op_cwd(state: &mut State, _args: Value) -> Result<String, AnyError> {
+  if let Some(config_specifier) = &state.maybe_config_specifier {
+    let cwd = config_specifier.join("./")?;
+    Ok(cwd.to_string())
+  } else {
+    Ok("cache:///".to_string())
+  }
+}
+
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "camelCase")]
 struct EmitArgs {
@@ -285,7 +312,7 @@ fn op_emit(state: &mut State, args: Value) -> Result<Value, AnyError> {
             } else if let Some(remapped_specifier) = state.root_map.get(s) {
               remapped_specifier.clone()
             } else {
-              resolve_url_or_path(s).unwrap()
+              normalize_specifier(s).unwrap()
             }
           })
           .collect();
@@ -300,6 +327,25 @@ fn op_emit(state: &mut State, args: Value) -> Result<Value, AnyError> {
   Ok(json!(true))
 }
 
+#[derive(Debug, Deserialize)]
+struct ExistsArgs {
+  /// The fully qualified specifier that should be loaded.
+  specifier: String,
+}
+
+fn op_exists(state: &mut State, args: ExistsArgs) -> Result<bool, AnyError> {
+  if let Ok(specifier) = normalize_specifier(&args.specifier) {
+    if specifier.scheme() == "asset" || specifier.scheme() == "data" {
+      Ok(true)
+    } else {
+      let graph = state.graph.lock();
+      Ok(graph.contains(&specifier))
+    }
+  } else {
+    Ok(false)
+  }
+}
+
 #[derive(Debug, Deserialize)]
 struct LoadArgs {
   /// The fully qualified specifier that should be loaded.
@@ -309,7 +355,7 @@ struct LoadArgs {
 fn op_load(state: &mut State, args: Value) -> Result<Value, AnyError> {
   let v: LoadArgs = serde_json::from_value(args)
     .context("Invalid request from JavaScript for \"op_load\".")?;
-  let specifier = resolve_url_or_path(&v.specifier)
+  let specifier = normalize_specifier(&v.specifier)
     .context("Error converting a string module specifier for \"op_load\".")?;
   let mut hash: Option<String> = None;
   let mut media_type = MediaType::Unknown;
@@ -328,7 +374,7 @@ fn op_load(state: &mut State, args: Value) -> Result<Value, AnyError> {
     media_type = MediaType::from(&v.specifier);
     maybe_source
   } else {
-    let graph = state.graph.lock().unwrap();
+    let graph = state.graph.lock();
     let specifier = if let Some(data_specifier) =
       state.data_url_map.get(&v.specifier)
     {
@@ -372,7 +418,7 @@ fn op_resolve(state: &mut State, args: Value) -> Result<Value, AnyError> {
   } else if let Some(remapped_base) = state.root_map.get(&v.base) {
     remapped_base.clone()
   } else {
-    resolve_url_or_path(&v.base).context(
+    normalize_specifier(&v.base).context(
       "Error converting a string module specifier for \"op_resolve\".",
     )?
   };
@@ -383,7 +429,7 @@ fn op_resolve(state: &mut State, args: Value) -> Result<Value, AnyError> {
         MediaType::from(specifier).as_ts_extension().to_string(),
       ));
     } else {
-      let graph = state.graph.lock().unwrap();
+      let graph = state.graph.lock();
       match graph.resolve(specifier, &referrer, true) {
         Ok(resolved_specifier) => {
           let media_type = if let Some(media_type) =
@@ -490,14 +536,17 @@ pub fn exec(request: Request) -> Result<Response, AnyError> {
     op_state.put(State::new(
       request.graph.clone(),
       request.hash_data.clone(),
+      request.maybe_config_specifier.clone(),
       request.maybe_tsbuildinfo.clone(),
       root_map,
       data_url_map,
     ));
   }
 
+  runtime.register_op("op_cwd", op(op_cwd));
   runtime.register_op("op_create_hash", op(op_create_hash));
   runtime.register_op("op_emit", op(op_emit));
+  runtime.register_op("op_exists", op(op_exists));
   runtime.register_op("op_load", op(op_load));
   runtime.register_op("op_resolve", op(op_resolve));
   runtime.register_op("op_respond", op(op_respond));
@@ -513,9 +562,9 @@ pub fn exec(request: Request) -> Result<Response, AnyError> {
   let exec_source = format!("globalThis.exec({})", request_str);
 
   runtime
-    .execute("[native code]", startup_source)
+    .execute_script(&located_script_name!(), startup_source)
     .context("Could not properly start the compiler runtime.")?;
-  runtime.execute("[native_code]", &exec_source)?;
+  runtime.execute_script(&located_script_name!(), &exec_source)?;
 
   let op_state = runtime.op_state();
   let mut op_state = op_state.borrow_mut();
@@ -546,9 +595,9 @@ mod tests {
   use crate::diagnostics::DiagnosticCategory;
   use crate::module_graph::tests::MockSpecifierHandler;
   use crate::module_graph::GraphBuilder;
+  use deno_core::parking_lot::Mutex;
   use std::env;
   use std::path::PathBuf;
-  use std::sync::Mutex;
 
   async fn setup(
     maybe_specifier: Option<ModuleSpecifier>,
@@ -573,6 +622,7 @@ mod tests {
     State::new(
       graph,
       hash_data,
+      None,
       maybe_tsbuildinfo,
       HashMap::new(),
       HashMap::new(),
@@ -614,6 +664,7 @@ mod tests {
       debug: false,
       graph,
       hash_data,
+      maybe_config_specifier: None,
       maybe_tsbuildinfo: None,
       root_names: vec![(specifier.clone(), MediaType::TypeScript)],
     };
@@ -627,7 +678,7 @@ mod tests {
       ..Default::default()
     });
     js_runtime
-      .execute(
+      .execute_script(
         "<anon>",
         r#"
       if (!(startup)) {
